Welcome to ClientVPS Mirrors

Help for package samplex
Title: Shiny Tool for Sample Size Calculation
Version: 0.3.0
Description: An interactive 'shiny' application to assist in determining sample sizes for common survey designs such as 'simple random sampling', 'stratified sampling', and 'cluster sampling'. It includes formulas, helper calculators, and illustrative examples.
License: MIT + file LICENSE
Depends: R (≥ 3.5)
Imports: shiny
Suggests: knitr, rmarkdown, DT, dplyr
VignetteBuilder: knitr
Encoding: UTF-8
Language: en
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-10-26 09:15:59 UTC; grami
Author: Gustavo Ramirez-Valverde [aut, cre], Benito Ramirez-Valverde [aut]
Maintainer: Gustavo Ramirez-Valverde <gramirez@colpos.mx>
Repository: CRAN
Date/Publication: 2025-10-29 20:10:02 UTC

Launch the Shiny application samplex

Description

Opens the Shiny app included in the package.

Usage

samplex()

Value

Nothing; launches the Shiny app.

Examples

if (interactive()) samplex()

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.